@@ -5,11 +5,12 @@
 # published by the Free Software Foundation
 
 import os
-import util
 
-from plugins.events import EventPlugin
+from quodlibet import util
+from quodlibet.const import USERDIR
+from quodlibet.plugins.events import EventPlugin
 
-outfile = os.path.expanduser("~/.quodlibet/jabber")
+outfile = os.path.join(USERDIR, "jabber")
 format = """\
 <tune xmlns='http://jabber.org/protocol/tune'>
  <artist>%s</artist>
@@ -18,7 +19,7 @@ format = """\
  <track>%d</track>
  <length>%d</length>
 </tune>"""
-    
+
 class JEP118(EventPlugin):
     PLUGIN_ID = "JEP-118"
     PLUGIN_NAME = "JEP-118"
@@ -40,6 +41,6 @@ class JEP118(EventPlugin):
                     util.escape(song.comma("artist")),
                     util.escape(song.comma("title")),
                     util.escape(song.comma("album")),
-                    song("~#track", 0), song("~#length")))
+                    song("~#track", 0), song.get("~#length", 0)))
             except EnvironmentError: pass
             else: f.close()
