@@ -5,6 +5,7 @@
 # published by the Free Software Foundation.
 
 import time
+import tempfile
 
 import gtk
 import dbus
@@ -263,11 +264,11 @@ class MPRIS1PlayerObject(MPRISObject):
     unpaused = paused
 
     def song_started(self, song):
-        self.TrackChanged(self._get_metadata(song))
+        self.TrackChange(self._get_metadata(song))
 
     def __update_track_changed(self, library, songs):
         if player.info in songs:
-             self.TrackChanged(self._get_metadata(player.info))
+             self.TrackChange(self._get_metadata(player.info))
 
     def __update_status(self, *args):
         self.StatusChange(self.__get_status())
@@ -298,17 +299,34 @@ class MPRIS1PlayerObject(MPRISObject):
             if val:
                 metadata[key] = val
 
-        metadata["audio-bitrate"] = song("~#bitrate", 0) * 1024
-        metadata["rating"] = int(round(song("~#rating") * 5))
-        metadata["year"] = song("~#year", 0)
-        metadata["time"] = song("~#length", 0)
-        metadata["mtime"] = song("~#length", 0) * 1000
+        nums = [("audio-bitrate", 1024, "~#bitrate"),
+                ("rating", 5, "~#rating"),
+                ("year", 1, "~#year"),
+                ("time", 1, "~#length"),
+                ("mtime", 1000, "~#length")]
+
+        for target, mul, key in nums:
+            value = song(key, None)
+            if value is None:
+                continue
+            value = int(value * mul)
+            # dbus uses python types to guess the dbus type without
+            # checking maxint, also we need uint (dbus always trys int)
+            try: value = dbus.UInt32(value)
+            except OverflowError: continue
+            metadata[target] = value
 
         year = song("~year")
         if year:
             try: tuple_time = time.strptime(year, "%Y")
             except ValueError: pass
-            else: metadata["date"] = int(time.mktime(tuple_time))
+            else:
+                try:
+                    date = int(time.mktime(tuple_time))
+                    date = dbus.UInt32(date)
+                except (ValueError, OverflowError): pass
+                else:
+                    metadata["date"] = date
 
         return metadata
 
@@ -338,7 +356,8 @@ class MPRIS1PlayerObject(MPRISObject):
 
     @dbus.service.method(dbus_interface=__interface)
     def Stop(self):
-        player.stop()
+        player.paused = True
+        player.seek(0)
 
     @dbus.service.method(dbus_interface=__interface)
     def Play(self):
@@ -384,7 +403,7 @@ class MPRIS1PlayerObject(MPRISObject):
         return int(player.get_position())
 
     @dbus.service.signal(__interface, signature="a{sv}")
-    def TrackChanged(self, metadata):
+    def TrackChange(self, metadata):
         pass
 
     @dbus.service.signal(__interface, signature="(iiii)")
@@ -404,26 +423,28 @@ class MPRIS2Object(MPRISObject):
     __prop_interface = "org.freedesktop.DBus.Properties"
     __introspect_interface = "org.freedesktop.DBus.Introspectable"
 
-    def __get_playback_status():
+    def __get_playback_status(self):
+        if not player.song or (player.paused and not player.get_position()):
+            return "Stopped"
         return ("Playing", "Paused")[int(player.paused)]
 
-    def __get_loop_status():
+    def __get_loop_status(self):
         return ("None", "Playlist")[int(window.repeat.get_active())]
 
-    def __set_loop_status(value):
+    def __set_loop_status(self, value):
         window.repeat.set_active(value == "Playlist")
 
-    def __get_shuffle():
+    def __get_shuffle(self):
         return (window.order.get_active_name() == "shuffle")
 
-    def __set_shuffle(value):
+    def __set_shuffle(self, value):
         shuffle_on = window.order.get_active_name() == "shuffle"
         if shuffle_on and not value:
             window.order.set_active("inorder")
         elif not shuffle_on and value:
             window.order.set_active("shuffle")
 
-    def __get_metadata():
+    def __get_metadata(self):
         """http://xmms2.org/wiki/MPRIS_Metadata"""
         song = player.info
 
@@ -432,16 +453,23 @@ class MPRIS2Object(MPRISObject):
         if not song: return metadata
 
         metadata["mpris:trackid"] += str(id(song))
-        metadata["mpris:length"] = long(player.info.get("~#length", 0) * 1000)
-        cover = song.find_cover()
+        metadata["mpris:length"] = \
+            long(player.info.get("~#length", 0) * 1000000)
+
+        self.__cover = cover = song.find_cover()
+        is_temp = False
         if cover:
             name = cover.name
+            is_temp = name.startswith(tempfile.gettempdir())
             if isinstance(name, str):
                 name = util.fsdecode(name)
             # This doesn't work for embedded images.. the file gets unlinked
             # after loosing the file handle
             metadata["mpris:artUrl"] = str(URI.frompath(name))
 
+        if not is_temp:
+            self.__cover = None
+
         # All list values
         list_val = {"artist": "artist", "albumArtist": "albumartist",
             "comment": "comment", "composer": "composer", "genre": "genre",
@@ -482,18 +510,20 @@ class MPRIS2Object(MPRISObject):
             try: tuple_time = time.strptime(year, "%Y")
             except ValueError: pass
             else:
-                iso_time = time.strftime(ISO_8601_format, tuple_time)
-                metadata["xesam:contentCreated"] = iso_time
+                try: iso_time = time.strftime(ISO_8601_format, tuple_time)
+                except ValueError: pass
+                else:
+                    metadata["xesam:contentCreated"] = iso_time
 
         return metadata
 
-    def __get_volume():
+    def __get_volume(self):
         return float(player.volume)
 
-    def __set_volume(value):
+    def __set_volume(self, value):
         player.volume = max(0, value)
 
-    def __get_position():
+    def __get_position(self):
         return long(player.get_position()*1000)
 
     __root_interface = "org.mpris.MediaPlayer2"
@@ -508,33 +538,34 @@ class MPRIS2Object(MPRISObject):
     }
 
     __player_interface = "org.mpris.MediaPlayer2.Player"
-    __player_props = {
-        "PlaybackStatus": (__get_playback_status, None),
-        "LoopStatus": (__get_loop_status, __set_loop_status),
-        "Rate": (1.0, None),
-        "Shuffle": (__get_shuffle, __set_shuffle),
-        "Metadata": (__get_metadata, None),
-        "Volume": (__get_volume, __set_volume),
-        "Position": (__get_position, None),
-        "MinimumRate": (1.0, None),
-        "MaximumRate": (1.0, None),
-        "CanGoNext": (True, None), # Pretend we can do everything for now
-        "CanGoPrevious": (True, None),
-        "CanPlay": (True, None),
-        "CanPause": (True, None),
-        "CanSeek": (True, None),
-        "CanControl": (True, None),
-    }
-
-    __prop_mapping = {
-        __player_interface: __player_props,
-        __root_interface: __root_props}
 
     def __init__(self):
         bus = dbus.SessionBus()
         name = dbus.service.BusName(self.__bus_name, bus)
         super(MPRIS2Object, self).__init__(name, self.__path)
 
+        self.__player_props = {
+            "PlaybackStatus": (self.__get_playback_status, None),
+            "LoopStatus": (self.__get_loop_status, self.__set_loop_status),
+            "Rate": (1.0, None),
+            "Shuffle": (self.__get_shuffle, self.__set_shuffle),
+            "Metadata": (self.__get_metadata, None),
+            "Volume": (self.__get_volume, self.__set_volume),
+            "Position": (self.__get_position, None),
+            "MinimumRate": (1.0, None),
+            "MaximumRate": (1.0, None),
+            "CanGoNext": (True, None), # Pretend we can do everything for now
+            "CanGoPrevious": (True, None),
+            "CanPlay": (True, None),
+            "CanPause": (True, None),
+            "CanSeek": (True, None),
+            "CanControl": (True, None),
+        }
+
+        self.__prop_mapping = {
+            self.__player_interface: self.__player_props,
+            self.__root_interface: self.__root_props}
+
         self.__rsig = window.repeat.connect_object(
             "toggled", self.__update_property,
             self.__player_interface, "LoopStatus")
@@ -547,6 +578,10 @@ class MPRIS2Object(MPRISObject):
             "changed", self.__update_metadata_changed,
             self.__player_interface, "Metadata")
 
+        self.__seek_sig = player.connect("seek", self.__seeked)
+
+        self.__update_property(self.__player_interface, "Metadata")
+
     def paused(self):
         self.__update_property(self.__player_interface, "PlaybackStatus")
     unpaused = paused
@@ -558,9 +593,11 @@ class MPRIS2Object(MPRISObject):
     def remove_from_connection(self, *arg, **kwargs):
         super(MPRIS2Object, self).remove_from_connection(*arg, **kwargs)
 
+        self.__cover = None
         window.repeat.disconnect(self.__rsig)
         window.order.disconnect(self.__ssig)
         librarian.disconnect(self.__lsig)
+        player.disconnect(self.__seek_sig)
 
     def __update_metadata_changed(self, interface, song, prop):
         if song is player.info:
@@ -573,7 +610,7 @@ class MPRIS2Object(MPRISObject):
         self.PropertiesChanged(interface, {prop: val}, [])
 
     def __seeked(self, player, song, ms):
-        self.Seeked(long(ms * 1000))
+        self.Seeked(ms * 1000)
 
     @dbus.service.method(__introspect_interface)
     def Introspect(self):
@@ -620,7 +657,8 @@ class MPRIS2Object(MPRISObject):
 
     @dbus.service.method(__player_interface)
     def Stop(self):
-        player.stop()
+        player.paused = True
+        player.seek(0)
 
     @dbus.service.method(__player_interface, in_signature="x")
     def Seek(self, offset):
