@@ -362,7 +362,7 @@ class DiscogsParser(object):
         return dom
 
     def __parse_list(self, dom):
-        """Returns a list with the album name and the release ID.
+        """Returns a list with the album name and the uri.
         Since the naming of releases in the specific release pages
         seems complex.. use the one from the search result page."""
 
@@ -370,24 +370,24 @@ class DiscogsParser(object):
         results = dom.getElementsByTagName('result')
         for result in results:
             uri_tag = result.getElementsByTagName('uri')[0]
-            id = uri_tag.firstChild.data.split('/')[-1]
+            uri = uri_tag.firstChild.data
             name = result.getElementsByTagName('title')[0].firstChild.data
-            list.append((id, name))
+            list.append((uri, name))
 
         return list
 
-    def __parse_release(self, id, name):
+    def __parse_release(self, url, name):
         """Parse the release page and add the cover to the list."""
 
         if len(self.cover_list) >= self.limit:
             return
 
-        rel_url = self.url + '/release/' + id
         rel_paras = {}
         rel_paras['api_key'] = self.api_key
         rel_paras['f'] = 'xml'
 
-        data, enc = get_url(rel_url, get=rel_paras)
+        data, enc = get_url(url, get=rel_paras)
+
         dom = minidom.parseString(data)
 
         imgs = dom.getElementsByTagName('image')
@@ -437,14 +437,14 @@ class DiscogsParser(object):
             all = int(result[0].getAttribute('numResults'))
             end = int(result[0].getAttribute('end'))
 
-            ids = self.__parse_list(dom)
+            urls = self.__parse_list(dom)
 
             thread_list = []
-            for id, name in ids:
+            for url, name in urls:
                 self.limit_count += 1
 
                 thr = threading.Thread(target=self.__parse_release,
-                    args=(id, name))
+                    args=(url, name))
                 thr.setDaemon(True)
                 thr.start()
                 thread_list.append(thr)
@@ -463,7 +463,6 @@ class DiscogsParser(object):
                 break
 
             page += 1
-
         return self.cover_list
 
 class AmazonParser(object):
@@ -571,107 +570,6 @@ class AmazonParser(object):
 
         return self.covers
 
-class DarktownParser(BasicHTMLParser):
-    """A class for searching covers from darktown.to"""
-
-    def __init__(self):
-        super(DarktownParser, self).__init__()
-
-        self.root_url = 'http://www.darktown.ws'
-        self.page_count = 0
-        self.limit = 0
-        self.covers = []
-
-        self.main_links = []
-
-    def start(self, query, limit=10):
-        """Start the search and returns the covers"""
-
-        self.page_count = 0
-        self.limit = limit
-        #site only takes and returns latin-1
-
-        enc = get_encoding(self.root_url)
-        query = query.decode('utf-8').encode(enc)
-        self.covers = []
-        self.main_links = []
-
-        #get first page
-        self.__parse_page(1, query)
-
-        #look if there are more
-        self.__parse_page_count()
-
-        #parse all the cover urls from page 1
-        self.__parse_search_list()
-
-        #do the same for the rest until the limit is reached
-        for i in xrange(2, min(limit / 100, self.page_count) + 1):
-            self.__parse_page(i, query)
-            self.__parse_search_list()
-
-        #go to each url and get all the infos
-        self.__parse_all_covers()
-
-        #delete all the parsed data
-        del self.data
-
-        return self.covers
-
-    def __parse_all_covers(self):
-        """Reads all URLs and adds the covers to the list"""
-
-        for link in self.main_links:
-            self.parse_url(self.root_url + link)
-
-            cover = {}
-            cover['source'] = self.root_url
-
-            for tag in xrange(len(self.data)):
-                if self.data[tag][0] == 'img' and 'thumbnail' not in cover:
-                    cover['thumbnail'] = self.data[tag][1]['src']
-                elif self.data[tag][0] == 'a' and 'cover' not in cover:
-                    cover['cover'] = self.data[tag][1]['href']
-                elif self.data[tag][0] == 'font' and 'size' in \
-                    self.data[tag][1] and self.data[tag][1]['size'] == '4':
-                    cover['name'] = (self.data[tag][2] + ' - ' + \
-                        self.data[tag + 2][2]).strip()
-                    cover['size'] = self.data[tag + 13][2].strip()
-
-            self.covers.append(cover)
-
-    def __parse_page(self, page, query):
-        """Parses the search result page and saves the data to self.data"""
-
-        params = {'action': 'search', 'what': query, \
-            'category': 'audio', 'page': page}
-        self.parse_url(self.root_url + '/search.php', get=params)
-
-    def __parse_page_count(self):
-        """Tries to figure out how many result pages we got."""
-
-        for i in self.data:
-            if 'href' in i[1]:
-                if i[1]['href'].startswith('/search.php') \
-                    and not i[2].isdigit():
-                    start = i[1]['href'].rfind('=') + 1
-                    self.page_count = int(i[1]['href'][start:])
-                    break
-                elif i[1]['href'].startswith('javascript:'):
-                    break
-
-    def __parse_search_list(self):
-        """Extracts all album urls from the result page"""
-
-        for tag in self.data:
-            if tag[0] == 'a':
-                split = tag[1]['href'].split('\'')
-                if len(split) > 1 and split[1].endswith('&type=Front'):
-                    self.main_links.append(split[1])
-
-            if len(self.main_links) >= self.limit:
-                break
-
 class CoverArea(gtk.VBox):
     """The image display and saving part."""
 
@@ -1118,7 +1016,7 @@ class AlbumArtWindow(qltk.Window):
     def __add_cover_to_list(self, cover):
         try:
             pbloader = gtk.gdk.PixbufLoader()
-            pbloader.write(urllib.urlopen(cover['thumbnail']).read())
+            pbloader.write(get_url(cover['thumbnail'])[0])
             pbloader.close()
 
             size = 48
@@ -1133,7 +1031,9 @@ class AlbumArtWindow(qltk.Window):
         except gobject.GError, IOError:
             pass
         else:
-            self.liststore.append([thumb, cover])
+            def append(data):
+                self.liststore.append(data)
+            gobject.idle_add(append, [thumb, cover])
 
     def __search_callback(self, covers, progress):
         for cover in covers:
@@ -1280,15 +1180,6 @@ def get_size_of_url(url):
 #------------------------------------------------------------------------------
 engines = []
 
-#-------
-eng = {}
-eng['class'] = DarktownParser
-eng['url'] = 'http://www.darktown.ws/'
-eng['replace'] = ' '
-eng['config_id'] = 'darktown'
-
-engines.append(eng)
-
 #-------
 eng = {}
 eng['class'] = CoverParadiseParser
