@@ -15,14 +15,14 @@ import time
 import gtk
 import gobject
 import pango
+from musicbrainz2 import webservice as ws
+from musicbrainz2.utils import extractUuid
 
 from quodlibet import config, util
 from quodlibet.qltk.ccb import ConfigCheckButton
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.qltk.views import HintedTreeView, MultiDragTreeView
 
-from musicbrainz2 import webservice as ws
-from musicbrainz2.utils import extractUuid
 VARIOUS_ARTISTS_ARTISTID = '89ad4ac3-39f7-470e-963a-56509c546377'
 
 def get_artist(album):
@@ -120,7 +120,10 @@ class ResultTreeView(HintedTreeView, MultiDragTreeView):
             self.model.remove(itr)
         self.remote_album = remote_album
         has_artists = bool(filter(lambda t: t.artist, remote_album))
-        self.get_column(3).set_visible(has_artists)
+        col = self.get_column(3)
+        # sometimes gets called after the treeview is already gone
+        if not col: return
+        col.set_visible(has_artists)
         self.columns_autosize()
         self.queue_draw()
 
@@ -172,7 +175,7 @@ class ReleaseEventComboBox(gtk.HBox):
         # the source for the 'labelid' tag, which we'll use until MB NGS is
         # up and running to deal with multi-disc albums properly. We sort to
         # find the earliest release with a catalog number.
-        events.sort(key=lambda e: (bool(not e.getCatalogNumber()), 
+        events.sort(key=lambda e: (bool(not e.getCatalogNumber()),
                                    e.getDate() or '9999-12-31'))
         for rel_event in events:
             text = '%s %s: <b>%s</b> <i>(%s)</i>' % (
@@ -261,6 +264,8 @@ class SearchWindow(gtk.Dialog):
             if (config_get('albumartist', True)
                 and extractUuid(album.artist.id) != VARIOUS_ARTISTS_ARTISTID):
                 shared['albumartist'] = album.artist.name
+                if config_get('artist_sort', True):
+                    shared['albumartistsort'] = album.artist.sortName
 
         if config_get('standard', True):
             shared['musicbrainz_albumartistid'] = extractUuid(album.artist.id)
@@ -278,8 +283,12 @@ class SearchWindow(gtk.Dialog):
                 song['musicbrainz_trackid'] = extractUuid(track.id)
             if album.isSingleArtistRelease() or not track.artist:
                 song['artist'] = album.artist.name
+                if config_get('artist_sort', True):
+                    song['artistsort'] = album.artist.sortName
             else:
                 song['artist'] = track.artist.name
+                if config_get('artist_sort', True):
+                    song['artistsort'] = track.artist.sortName
                 if config_get('standard', True):
                     song['musicbrainz_artistid'] = extractUuid(track.artist.id)
             if config_get('split_feat', False):
@@ -446,6 +455,7 @@ class MyBrainz(SongsMenuPlugin):
             ('split_feat', 'Split _featured performers from track', False),
             ('year_only', 'Only use year for "date" tag', False),
             ('albumartist', 'Write "_albumartist" when needed', True),
+            ('artist_sort', 'Write sort tags for artist names', False),
             ('standard', 'Write _standard MusicBrainz tags', True),
             ('labelid', 'Write _labelid tag (fixes multi-disc albums)', True),
         ]
